@@ -76,17 +76,13 @@ struct _EogCloseConfirmationDialogPrivate
 };
 
 
-#define EOG_CLOSE_CONFIRMATION_DIALOG_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), \
-							EOG_TYPE_CLOSE_CONFIRMATION_DIALOG, \
-							EogCloseConfirmationDialogPrivate))
-
 #define GET_MODE(priv) (((priv->unsaved_images != NULL) && \
 			 (priv->unsaved_images->next == NULL)) ? \
 			  SINGLE_IMG_MODE : MULTIPLE_IMGS_MODE)
 
 #define IMAGE_COLUMN_HEIGHT 40
 
-G_DEFINE_TYPE(EogCloseConfirmationDialog, eog_close_confirmation_dialog, GTK_TYPE_DIALOG)
+G_DEFINE_TYPE_WITH_PRIVATE(EogCloseConfirmationDialog, eog_close_confirmation_dialog, GTK_TYPE_DIALOG)
 
 static void	 set_unsaved_image		(EogCloseConfirmationDialog *dlg,
 						 const GList		      *list);
@@ -174,19 +170,19 @@ add_buttons (EogCloseConfirmationDialog	       *dlg,
 
 	if (buttons & EOG_CLOSE_CONFIRMATION_DIALOG_CANCEL_BUTTON) {
 		gtk_dialog_add_button (GTK_DIALOG (dlg),
-				       GTK_STOCK_CANCEL,
+				       _("_Cancel"),
 				       EOG_CLOSE_CONFIRMATION_DIALOG_RESPONSE_CANCEL);
 	}
 
 	if (buttons & EOG_CLOSE_CONFIRMATION_DIALOG_SAVE_BUTTON) {
 		gtk_dialog_add_button (GTK_DIALOG (dlg),
-				       GTK_STOCK_SAVE,
+				       _("_Save"),
 				       EOG_CLOSE_CONFIRMATION_DIALOG_RESPONSE_SAVE);
 	}
 
 	if (buttons & EOG_CLOSE_CONFIRMATION_DIALOG_SAVEAS_BUTTON) {
 		gtk_dialog_add_button (GTK_DIALOG (dlg),
-				       GTK_STOCK_SAVE_AS,
+				       _("Save _As"),
 				       EOG_CLOSE_CONFIRMATION_DIALOG_RESPONSE_SAVEAS);
 	}
 
@@ -200,7 +196,7 @@ eog_close_confirmation_dialog_init (EogCloseConfirmationDialog *dlg)
 {
 	AtkObject *atk_obj;
 
-	dlg->priv = EOG_CLOSE_CONFIRMATION_DIALOG_GET_PRIVATE (dlg);
+	dlg->priv = eog_close_confirmation_dialog_get_instance_private (dlg);
 
 	gtk_container_set_border_width (GTK_CONTAINER (dlg), 5);
 	gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (dlg))), 14);
@@ -292,8 +288,6 @@ eog_close_confirmation_dialog_class_init (EogCloseConfirmationDialogClass *klass
 	gobject_class->get_property = eog_close_confirmation_dialog_get_property;
 	gobject_class->finalize = eog_close_confirmation_dialog_finalize;
 
-	g_type_class_add_private (klass, sizeof (EogCloseConfirmationDialogPrivate));
-
 	g_object_class_install_property (gobject_class,
 					 PROP_UNSAVED_IMAGES,
 					 g_param_spec_pointer ("unsaved_images",
@@ -623,8 +617,8 @@ build_multiple_imgs_dialog (EogCloseConfirmationDialog *dlg)
 			    hbox, TRUE, TRUE, 0);
 
 	/* Image */
-	image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_WARNING,
-					  GTK_ICON_SIZE_DIALOG);
+	image = gtk_image_new_from_icon_name ("dialog-warning",
+					      GTK_ICON_SIZE_DIALOG);
 	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
 	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
 
